@@ -3,13 +3,13 @@ Command Line Interface for Commit-Gen.
 """
 
 import argparse
-import sys
-import os
-import tty
-import termios
-import subprocess
-import tempfile
 import getpass
+import os
+import subprocess
+import sys
+import tempfile
+import termios
+import tty
 from typing import Optional, List
 
 from .config import (
@@ -27,24 +27,19 @@ from .config import (
     get_current_config,
     validate_provider,
     get_default_model_for_provider,
-    get_default_base_url_for_provider,
     provider_requires_api_key,
     list_providers,
 )
 from .core import (
     check_ollama,
     generate_changelog,
-    process_commit_generation,
-    DEBUG,
     debug_log,
 )
 from .git_utils import (
     get_modified_files,
     get_file_info,
-    get_file_category,
     stage_specific_files,
     get_staged_files,
-    clear_staging_area,
     is_git_repository,
     create_git_commit,
     push_to_origin,
@@ -103,36 +98,36 @@ def edit_commit_message(initial_message: str) -> str:
     print("-" * 30)
     print(initial_message)
     print("-" * 30)
-    
+
     while True:
         try:
             print("\nOptions:")
             print("1. Edit message")
             print("2. Use as-is")
             print("3. Cancel")
-            
+
             choice = input("\nEnter choice (1-3): ").strip()
-            
+
             if choice == "1":
                 # Use external editor if available, otherwise use input
                 editor = os.environ.get('EDITOR', 'nano')
-                
+
                 # Create temporary file with current message
                 with tempfile.NamedTemporaryFile(mode='w', suffix='.txt', delete=False) as f:
                     f.write(initial_message)
                     temp_file = f.name
-                
+
                 try:
                     # Open editor
                     subprocess.run([editor, temp_file], check=True)
-                    
+
                     # Read edited message
                     with open(temp_file, 'r') as f:
                         edited_message = f.read().strip()
-                    
+
                     # Clean up
                     os.unlink(temp_file)
-                    
+
                     if edited_message:
                         print(f"\n✅ Updated commit message:")
                         print("-" * 30)
@@ -141,12 +136,12 @@ def edit_commit_message(initial_message: str) -> str:
                         return edited_message
                     else:
                         print("❌ Commit message cannot be empty. Please try again.")
-                        
+
                 except (subprocess.CalledProcessError, FileNotFoundError):
                     # Fallback to simple input if editor not available
                     print(f"\nEditor '{editor}' not found. Using simple input mode.")
                     print("Enter your commit message (press Enter twice to finish):")
-                    
+
                     lines = []
                     while True:
                         try:
@@ -157,13 +152,13 @@ def edit_commit_message(initial_message: str) -> str:
                         except KeyboardInterrupt:
                             print("\n\n👋 Goodbye! Exiting gracefully...")
                             sys.exit(0)
-                    
+
                     edited_message = "\n".join(lines).strip()
                     if edited_message:
                         return edited_message
                     else:
                         print("❌ Commit message cannot be empty. Please try again.")
-                        
+
             elif choice == "2":
                 return initial_message
             elif choice == "3":
@@ -184,17 +179,17 @@ def confirm_commit(commit_message: str, auto_push: bool = False) -> str:
     print("-" * 30)
     print(commit_message)
     print("-" * 30)
-    
+
     if auto_push:
         print("\nOptions:")
         print("1. ✅ Yes, commit and push")
         print("2. ❌ No, go back to editing")
         print("3. 🚪 Cancel")
-        
+
         while True:
             try:
                 choice = input("\nEnter choice (1-3): ").strip()
-                
+
                 if choice == "1":
                     return "commit_and_push"
                 elif choice == "2":
@@ -213,11 +208,11 @@ def confirm_commit(commit_message: str, auto_push: bool = False) -> str:
         print("2. 🚀 Yes, commit and push")
         print("3. ❌ No, go back to editing")
         print("4. 🚪 Cancel")
-        
+
         while True:
             try:
                 choice = input("\nEnter choice (1-4): ").strip()
-                
+
                 if choice == "1":
                     return "commit"
                 elif choice == "2":
@@ -239,32 +234,32 @@ def interactive_file_selection() -> List[str]:
     if not is_git_repository():
         print("❌ Not in a git repository. Please run this command in a git repository.")
         sys.exit(1)
-    
+
     # Get modified files
     modified_files = get_modified_files()
-    
+
     if not modified_files:
         print("📁 No modified files found.")
         print("💡 Make some changes to files first, then run commit-gen again.")
         return []
-    
+
     # Get already staged files
     staged_files = get_staged_files()
-    
+
     # Sort files alphabetically for simple navigation
     modified_files.sort(key=lambda x: x["filename"])
-    
+
     # Prepare simple file list
     display_files = []
     file_to_display_index = {}
-    
+
     for i, file_info in enumerate(modified_files):
         filename = file_info["filename"]
         status = file_info["status"]
-        
+
         # Get additional file info
         file_details = get_file_info(filename)
-        
+
         # Add to display_files list
         display_files.append({
             "display_index": i,
@@ -274,54 +269,54 @@ def interactive_file_selection() -> List[str]:
             "staged": filename in staged_files
         })
         file_to_display_index[filename] = i
-    
+
     # Initialize selection state
     selected_files = set()
     current_index = 0
-    
+
     # Auto-select already staged files
     for filename in staged_files:
         if filename in file_to_display_index:
             selected_files.add(filename)
-    
+
     while True:
         clear_screen()
-        
+
         print("📁 Files to commit:")
         print("=" * 60)
         print("Use ↑/↓ to navigate, SPACE to toggle, ENTER to confirm")
         print("a=select all, n=select none, s=skip (stage all), q=quit")
         print()
-        
+
         # Display files in simple list
         for i, file_info in enumerate(display_files):
             filename = file_info["filename"]
             status = file_info["status"]
             size = file_info["size"]
-            
+
             # Check if selected
             is_selected = filename in selected_files
             checkbox = "[x]" if is_selected else "[ ]"
-            
+
             # Check if current selection
             cursor = "→" if i == current_index else " "
-            
+
             # Check if already staged
             staged_marker = " ✅" if filename in staged_files else ""
-            
+
             print(f"{cursor} {checkbox} {filename} ({status}, {size}){staged_marker}")
-        
+
         print()
-        
+
         # Show selection summary
         selected_count = len(selected_files)
         total_count = len(display_files)
         print(f"Selected: {selected_count}/{total_count} files")
         print()
-        
+
         # Get user input
         key = get_key()
-        
+
         if key == 'UP':
             current_index = max(0, current_index - 1)
         elif key == 'DOWN':
@@ -359,14 +354,14 @@ def interactive_file_selection() -> List[str]:
             else:
                 print("❌ No files selected. Please select at least one file.")
                 input("Press Enter to continue...")
-    
+
     return []
 
 
 def print_config():
     """Print current configuration."""
     config = get_current_config()
-    
+
     print("🔧 Current Configuration")
     print("=" * 50)
     print(f"Provider: {config['provider_name']} ({config['provider']})")
@@ -380,7 +375,7 @@ def print_config():
 def print_providers():
     """Print available providers."""
     providers = list_providers()
-    
+
     print("🤖 Available Providers")
     print("=" * 50)
     for i, (key, provider) in enumerate(providers.items(), 1):
@@ -396,20 +391,20 @@ def interactive_setup():
     try:
         print("🤖 Commit-Gen Setup Wizard")
         print("=" * 50)
-        
+
         # Show current config
         config = get_current_config()
         print(f"Current provider: {config['provider_name']}")
         print()
-        
+
         # Show available providers
         providers = list_providers()
         provider_keys = list(providers.keys())
-        
+
         print("Available providers:")
         for i, (key, provider) in enumerate(providers.items(), 1):
             print(f"{i}. {provider['name']} - {provider['description']}")
-        
+
         # Get provider choice
         while True:
             try:
@@ -425,22 +420,22 @@ def interactive_setup():
             except KeyboardInterrupt:
                 print("\n\n👋 Goodbye! Exiting gracefully...")
                 sys.exit(0)
-        
+
         provider_info = providers[selected_provider]
         print(f"\nSetting up {provider_info['name']}...")
-        
+
         # Set provider
         save_provider(selected_provider)
         save_base_url(provider_info['base_url'])
-        
+
         # Clear existing model to avoid conflicts
         save_model("")
-        
+
         # Handle model configuration
         default_model = provider_info['default_model']
         print(f"\n📋 Model Configuration")
         print(f"Default model: {default_model}")
-        
+
         while True:
             try:
                 model_choice = input(f"Use default model '{default_model}'? (y/n): ").strip().lower()
@@ -467,12 +462,12 @@ def interactive_setup():
             except KeyboardInterrupt:
                 print("\n\n👋 Goodbye! Exiting gracefully...")
                 sys.exit(0)
-        
+
         # Handle base URL for custom provider
         if selected_provider == "custom":
             print(f"\n🌐 Base URL Configuration")
             print(f"Default base URL: {provider_info['base_url']}")
-            
+
             while True:
                 try:
                     url_choice = input(f"Use default base URL '{provider_info['base_url']}'? (y/n): ").strip().lower()
@@ -502,7 +497,7 @@ def interactive_setup():
                 except KeyboardInterrupt:
                     print("\n\n👋 Goodbye! Exiting gracefully...")
                     sys.exit(0)
-        
+
         # Handle API key if required
         if provider_info['requires_api_key']:
             print(f"\n🔑 API Key Configuration")
@@ -516,9 +511,9 @@ def interactive_setup():
             except KeyboardInterrupt:
                 print("\n\n👋 Goodbye! Exiting gracefully...")
                 sys.exit(0)
-        
+
         print("\n✅ Setup completed successfully!")
-        
+
     except KeyboardInterrupt:
         print("\n\n👋 Goodbye! Exiting gracefully...")
         sys.exit(0)
@@ -532,19 +527,19 @@ def set_provider_command(provider: str):
         for key, info in PROVIDERS.items():
             print(f"  - {key}: {info['name']}")
         sys.exit(1)
-    
+
     provider_info = PROVIDERS[provider]
     save_provider(provider)
     save_base_url(provider_info['base_url'])
-    
+
     # Clear existing model to avoid conflicts
     save_model("")
-    
+
     # Don't automatically set model - let user decide
     print(f"✅ Provider set to {provider_info['name']}")
     print(f"Base URL: {provider_info['base_url']}")
     print(f"Default model: {provider_info['default_model']}")
-    
+
     # Check if model is already set
     current_model = get_model()
     if current_model:
@@ -552,7 +547,7 @@ def set_provider_command(provider: str):
     else:
         print(f"Model not set. Use default or set custom model:")
         print(f"  commit-gen --set-model {provider_info['default_model']}")
-    
+
     if provider_info['requires_api_key']:
         current_api_key = get_api_key()
         if current_api_key:
@@ -569,7 +564,7 @@ def set_api_key_command(api_key: str):
         if not api_key:
             print("❌ No API key provided.")
             return
-    
+
     save_api_key(api_key)
     print("✅ API key saved")
 
@@ -586,39 +581,40 @@ def set_base_url_command(base_url: str):
     print(f"✅ Base URL set to {base_url}")
 
 
-def process_commit_with_confirmation(provider: str, api_key: str, model: str, custom_prompt: Optional[str], auto_push: bool = False):
+def process_commit_with_confirmation(provider: str, api_key: str, model: str, custom_prompt: Optional[str],
+                                     auto_push: bool = False):
     """Process commit generation with confirmation steps."""
     from .core import generate_commit_message
     from .git_utils import get_git_diff
-    
+
     print("🤖 Generating commit message...")
-    
+
     # Get git diff content
     diff_content = get_git_diff()
     if not diff_content:
         print("❌ No changes found to commit.")
         sys.exit(1)
-    
+
     # Generate commit message
     commit_message = generate_commit_message(provider, api_key, model, custom_prompt, diff_content)
-    
+
     if not commit_message:
         print("❌ Failed to generate commit message.")
         sys.exit(1)
-    
+
     # Allow user to edit commit message
     final_message = edit_commit_message(commit_message)
-    
+
     # Confirm commit
     while True:
         choice = confirm_commit(final_message, auto_push)
-        
+
         if choice == "commit" or choice == "commit_and_push":
             # Perform commit
             try:
                 create_git_commit(final_message)
                 print("✅ Commit successful!")
-                
+
                 # Handle push if requested
                 if choice == "commit_and_push" or auto_push:
                     print("🚀 Pushing to remote...")
@@ -626,7 +622,7 @@ def process_commit_with_confirmation(provider: str, api_key: str, model: str, cu
                     print("✅ Push successful!")
                 else:
                     print("💡 To push changes, run: git push")
-                
+
                 break
             except Exception as e:
                 print(f"❌ Commit failed: {str(e)}")
@@ -644,31 +640,32 @@ def main() -> None:
     """Main CLI entry point."""
     try:
         parser = argparse.ArgumentParser(description="Generate commit messages using AI.")
-        
+
         # Main functionality
         parser.add_argument("--debug", action="store_true", help="Enable debug mode")
         parser.add_argument("--push", action="store_true", help="Push changes after commit")
         parser.add_argument("--changelog", action="store_true", help="Generate a changelog")
         parser.add_argument("--change-log", action="store_true", help="Generate a changelog (legacy option)")
-        parser.add_argument("--compare-branch", default="master", help="Branch to compare against when generating changelog")
+        parser.add_argument("--compare-branch", default="master",
+                            help="Branch to compare against when generating changelog")
         parser.add_argument("--changelog-file", default="CHANGELOG.md", help="Filename for the changelog")
-        
+
         # File selection options
         parser.add_argument("--all", action="store_true", help="Stage all files (default behavior)")
         parser.add_argument("--files", nargs="+", help="Stage specific files")
         parser.add_argument("--interactive", action="store_true", help="Interactive file selection")
-        
+
         # Configuration commands
         parser.add_argument("--setup", action="store_true", help="Interactive setup wizard")
         parser.add_argument("--config", action="store_true", help="Show current configuration")
         parser.add_argument("--providers", action="store_true", help="Show available providers")
-        
+
         # Provider and model settings
         parser.add_argument("--set-provider", help="Set provider (openrouter, ollama, gemini, mistral, custom)")
         parser.add_argument("--set-api-key", nargs="?", const="", help="Set API key (leave empty for secure input)")
         parser.add_argument("--set-model", help="Set model name")
         parser.add_argument("--set-base-url", help="Set base URL for custom provider")
-        
+
         # Legacy options (for backward compatibility)
         parser.add_argument("--provider", choices=list(PROVIDERS.keys()), help="Set the provider (legacy)")
         parser.add_argument("--model", help="Set the model name (legacy)")
@@ -676,7 +673,11 @@ def main() -> None:
         parser.add_argument("--base-url", help="Set the base URL for custom provider (legacy)")
         parser.add_argument("--prompt", help="Set a custom prompt")
         parser.add_argument("--save-prompt", help="Save custom prompt to file")
-        
+
+        # Prompt options
+        parser.add_argument("--prompt-file", help="Load custom prompt from file")
+        parser.add_argument("--save-prompt-file", help="Save current prompt to file")
+
         # Legacy provider flags
         parser.add_argument("--use-ollama", action="store_true", help="Use Ollama as the provider (legacy)")
         parser.add_argument("--use-openrouter", action="store_true", help="Use OpenRouter as the provider (legacy)")
@@ -692,28 +693,28 @@ def main() -> None:
         if args.config:
             print_config()
             return
-        
+
         if args.providers:
             print_providers()
             return
-        
+
         if args.setup:
             interactive_setup()
             return
-        
+
         # Handle new configuration commands
         if args.set_provider:
             set_provider_command(args.set_provider)
             return
-        
+
         if args.set_api_key is not None:
             set_api_key_command(args.set_api_key)
             return
-        
+
         if args.set_model:
             set_model_command(args.set_model)
             return
-        
+
         if args.set_base_url:
             set_base_url_command(args.set_base_url)
             return
@@ -748,7 +749,36 @@ def main() -> None:
 
         # Handle custom prompt
         custom_prompt = None
-        if args.save_prompt:
+
+        # Handle prompt file operations
+        if args.save_prompt_file:
+            try:
+                current_prompt = get_prompt()
+                if current_prompt:
+                    with open(args.save_prompt_file, "w") as f:
+                        f.write(current_prompt)
+                    print(f"✅ Current prompt saved to {args.save_prompt_file}")
+                else:
+                    print("❌ No current prompt to save")
+            except Exception as e:
+                print(f"❌ Error saving prompt to file: {str(e)}")
+                sys.exit(1)
+            return
+
+        # Load prompt from file
+        if args.prompt_file:
+            try:
+                with open(args.prompt_file, "r") as f:
+                    custom_prompt = f.read().strip()
+                print(f"✅ Loaded custom prompt from {args.prompt_file}")
+            except FileNotFoundError:
+                print(f"❌ Prompt file not found: {args.prompt_file}")
+                sys.exit(1)
+            except Exception as e:
+                print(f"❌ Error reading prompt file: {str(e)}")
+                sys.exit(1)
+        # Legacy prompt handling
+        elif args.save_prompt:
             try:
                 with open(args.save_prompt, "r") as f:
                     prompt_content = f.read()
@@ -762,7 +792,7 @@ def main() -> None:
 
         # Handle file staging
         files_staged = False
-        
+
         if args.files:
             # Stage specific files
             stage_specific_files(args.files)
@@ -785,7 +815,7 @@ def main() -> None:
             if selected_files:
                 stage_specific_files(selected_files)
                 files_staged = True
-        
+
         # Check if any files were successfully staged
         if not files_staged:
             print("❌ No files were staged. Please check your file selection.")
@@ -819,7 +849,7 @@ def main() -> None:
 
         # Process commit generation with confirmation
         process_commit_with_confirmation(provider, api_key, model, custom_prompt, args.push)
-        
+
     except KeyboardInterrupt:
         print("\n\n👋 Goodbye! Exiting gracefully...")
         sys.exit(0)
@@ -832,4 +862,4 @@ def main() -> None:
 
 
 if __name__ == "__main__":
-    main() 
\ No newline at end of file
+    main()
